summaryrefslogtreecommitdiffstats
path: root/tdecore
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-19 18:46:45 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-19 18:46:45 -0600
commit5bca2e3e42d02f8fed9ffc399ea14f8a05694cb0 (patch)
treed074ed35245d0d44f04cd625c1cafacdc15a13ae /tdecore
parent6e8a7cc94c1eb8b67e91e6dc2f864dfeec51d9cc (diff)
downloadtdelibs-5bca2e3e42d02f8fed9ffc399ea14f8a05694cb0.tar.gz
tdelibs-5bca2e3e42d02f8fed9ffc399ea14f8a05694cb0.zip
Rename KCmdLineArgs to TDECmdLineArgs to avoid conflicts with KDE4
Diffstat (limited to 'tdecore')
-rw-r--r--tdecore/kaboutdata.h4
-rw-r--r--tdecore/kapplication.cpp40
-rw-r--r--tdecore/kapplication.h10
-rw-r--r--tdecore/kcmdlineargs.cpp142
-rw-r--r--tdecore/kcmdlineargs.h46
-rw-r--r--tdecore/kconfig_compiler/example/autoexample.cpp2
-rw-r--r--tdecore/kconfig_compiler/example/example.cpp2
-rw-r--r--tdecore/kconfig_compiler/kconfig_compiler.cpp6
-rw-r--r--tdecore/kdetcompmgr.cpp4
-rw-r--r--tdecore/kinstance.h2
-rw-r--r--tdecore/klockfile.cpp2
-rw-r--r--tdecore/kuniqueapplication.cpp20
-rw-r--r--tdecore/kuniqueapplication.h12
-rw-r--r--tdecore/tde-config.cpp.cmake6
-rw-r--r--tdecore/tde-config.cpp.in6
-rw-r--r--tdecore/tests/kapptest.cpp2
-rw-r--r--tdecore/tests/kcalendartest.cpp6
-rw-r--r--tdecore/tests/kcmdlineargstest.cpp8
-rw-r--r--tdecore/tests/kglobaltest.cpp2
-rw-r--r--tdecore/tests/kmacroexpandertest.cpp2
-rw-r--r--tdecore/tests/kmdcodectest.cpp6
-rw-r--r--tdecore/tests/kresolvertest.cpp2
-rw-r--r--tdecore/tests/ksocktest.cpp2
-rw-r--r--tdecore/tests/kuniqueapptest.cpp2
-rw-r--r--tdecore/tests/kurltest.cpp2
-rw-r--r--tdecore/tests/startserviceby.cpp2
-rw-r--r--tdecore/tests/testqtargs.cpp12
27 files changed, 176 insertions, 176 deletions
diff --git a/tdecore/kaboutdata.h b/tdecore/kaboutdata.h
index 525ed3c92..9fe8d8593 100644
--- a/tdecore/kaboutdata.h
+++ b/tdecore/kaboutdata.h
@@ -48,7 +48,7 @@ class KAboutDataPrivate;
* about.addAuthor("Joe Developer", I18N_NOOP("developer"), "joe@host.com", 0);
* about.addCredit("Joe User", I18N_NOOP("A lot of bug reports"),
* "joe.user@host.org", 0);
- * KCmdLineArgs::init(argc, argv, &about);
+ * TDECmdLineArgs::init(argc, argv, &about);
* \endcode
*/
class TDECORE_EXPORT KAboutPerson
@@ -173,7 +173,7 @@ private:
*
* Currently, the values set here are shown by the "About" box
* (see KAboutDialog), used by the bug report dialog (see KBugReport),
- * and by the help shown on command line (see KCmdLineArgs).
+ * and by the help shown on command line (see TDECmdLineArgs).
*
* @short Holds information needed by the "About" box and other
* classes.
diff --git a/tdecore/kapplication.h b/tdecore/kapplication.h
index 2da1e0b82..6793c9510 100644
--- a/tdecore/kapplication.h
+++ b/tdecore/kapplication.h
@@ -111,7 +111,7 @@ public:
/**
* This constructor takes aboutData and command line
- * arguments from KCmdLineArgs.
+ * arguments from TDECmdLineArgs.
*
* If ARGB (transparent) widgets are to be used in your application,
* please use
@@ -234,7 +234,7 @@ public:
#endif
/**
- * @deprecated do not use it at all, it will make your application crash, use KCmdLineArgs
+ * @deprecated do not use it at all, it will make your application crash, use TDECmdLineArgs
*
* Constructor. Parses command-line arguments.
*
@@ -256,12 +256,12 @@ public:
* no styles either.
*/
// REMOVE FOR KDE 4.0 - using it only gives crashing applications because
- // KCmdLineArgs::init isn't called
+ // TDECmdLineArgs::init isn't called
KApplication(int& argc, char** argv,
const TQCString& rAppName, bool allowStyles=true, bool GUIenabled=true) KDE_DEPRECATED;
/**
- * Add Qt and KDE command line options to KCmdLineArgs.
+ * Add Qt and KDE command line options to TDECmdLineArgs.
*/
static void addCmdLineOptions();
@@ -1315,7 +1315,7 @@ private:
void init( bool GUIenabled );
- void parseCommandLine( ); // Handle KDE arguments (Using KCmdLineArgs)
+ void parseCommandLine( ); // Handle KDE arguments (Using TDECmdLineArgs)
void read_app_startup_id();
diff --git a/tdecore/kcmdlineargs.cpp b/tdecore/kcmdlineargs.cpp
index 75eb9d633..6550f9144 100644
--- a/tdecore/kcmdlineargs.cpp
+++ b/tdecore/kcmdlineargs.cpp
@@ -54,7 +54,7 @@
#endif
template class TQAsciiDict<TQCString>;
-template class TQPtrList<KCmdLineArgs>;
+template class TQPtrList<TDECmdLineArgs>;
class KCmdLineParsedOptions : public TQAsciiDict<TQCString>
{
@@ -104,27 +104,27 @@ public:
};
-class KCmdLineArgsList: public TQPtrList<KCmdLineArgs>
+class TDECmdLineArgsList: public TQPtrList<TDECmdLineArgs>
{
public:
- KCmdLineArgsList() { }
+ TDECmdLineArgsList() { }
};
-KCmdLineArgsList *KCmdLineArgs::argsList = 0;
-int KCmdLineArgs::argc = 0;
-char **KCmdLineArgs::argv = 0;
-char *KCmdLineArgs::mCwd = 0;
+TDECmdLineArgsList *TDECmdLineArgs::argsList = 0;
+int TDECmdLineArgs::argc = 0;
+char **TDECmdLineArgs::argv = 0;
+char *TDECmdLineArgs::mCwd = 0;
static KStaticDeleter <char> mCwdd;
-const KAboutData *KCmdLineArgs::about = 0;
-bool KCmdLineArgs::parsed = false;
-bool KCmdLineArgs::ignoreUnknown = false;
+const KAboutData *TDECmdLineArgs::about = 0;
+bool TDECmdLineArgs::parsed = false;
+bool TDECmdLineArgs::ignoreUnknown = false;
//
// Static functions
//
void
-KCmdLineArgs::init(int _argc, char **_argv, const char *_appname, const char* programName,
+TDECmdLineArgs::init(int _argc, char **_argv, const char *_appname, const char* programName,
const char *_description, const char *_version, bool noKApp)
{
init(_argc, _argv,
@@ -133,7 +133,7 @@ KCmdLineArgs::init(int _argc, char **_argv, const char *_appname, const char* pr
}
void
-KCmdLineArgs::init(int _argc, char **_argv, const char *_appname,
+TDECmdLineArgs::init(int _argc, char **_argv, const char *_appname,
const char *_description, const char *_version, bool noKApp)
{
init(_argc, _argv,
@@ -142,7 +142,7 @@ KCmdLineArgs::init(int _argc, char **_argv, const char *_appname,
}
void
-KCmdLineArgs::initIgnore(int _argc, char **_argv, const char *_appname )
+TDECmdLineArgs::initIgnore(int _argc, char **_argv, const char *_appname )
{
init(_argc, _argv,
new KAboutData(_appname, _appname, "unknown", "TDE Application", false));
@@ -150,7 +150,7 @@ KCmdLineArgs::initIgnore(int _argc, char **_argv, const char *_appname )
}
void
-KCmdLineArgs::init(const KAboutData* ab)
+TDECmdLineArgs::init(const KAboutData* ab)
{
char **_argv = (char **) malloc(sizeof(char *));
_argv[0] = (char *) ab->appName();
@@ -159,14 +159,14 @@ KCmdLineArgs::init(const KAboutData* ab)
void
-KCmdLineArgs::init(int _argc, char **_argv, const KAboutData *_about, bool noKApp)
+TDECmdLineArgs::init(int _argc, char **_argv, const KAboutData *_about, bool noKApp)
{
argc = _argc;
argv = _argv;
if (!argv)
{
- fprintf(stderr, "\n\nFAILURE (KCmdLineArgs):\n");
+ fprintf(stderr, "\n\nFAILURE (TDECmdLineArgs):\n");
fprintf(stderr, "Passing null-pointer to 'argv' is not allowed.\n\n");
assert( 0 );
@@ -191,30 +191,30 @@ KCmdLineArgs::init(int _argc, char **_argv, const KAboutData *_about, bool noKAp
KApplication::addCmdLineOptions();
}
-TQString KCmdLineArgs::cwd()
+TQString TDECmdLineArgs::cwd()
{
return TQFile::decodeName(TQCString(mCwd));
}
-const char * KCmdLineArgs::appName()
+const char * TDECmdLineArgs::appName()
{
if (!argc) return 0;
return argv[0];
}
void
-KCmdLineArgs::addCmdLineOptions( const KCmdLineOptions *options, const char *name,
+TDECmdLineArgs::addCmdLineOptions( const KCmdLineOptions *options, const char *name,
const char *id, const char *afterId)
{
if (!argsList)
- argsList = new KCmdLineArgsList();
+ argsList = new TDECmdLineArgsList();
int pos = argsList->count();
if (pos && id && argsList->last() && !argsList->last()->name)
pos--;
- KCmdLineArgs *args;
+ TDECmdLineArgs *args;
int i = 0;
for(args = argsList->first(); args; args = argsList->next(), i++)
{
@@ -230,12 +230,12 @@ KCmdLineArgs::addCmdLineOptions( const KCmdLineOptions *options, const char *nam
assert( parsed == false ); // You must add _ALL_ cmd line options
// before accessing the arguments!
- args = new KCmdLineArgs(options, name, id);
+ args = new TDECmdLineArgs(options, name, id);
argsList->insert(pos, args);
}
void
-KCmdLineArgs::saveAppArgs( TQDataStream &ds)
+TDECmdLineArgs::saveAppArgs( TQDataStream &ds)
{
if (!parsed)
parseAllArgs();
@@ -252,7 +252,7 @@ KCmdLineArgs::saveAppArgs( TQDataStream &ds)
if (!count) return;
- KCmdLineArgs *args;
+ TDECmdLineArgs *args;
for(args = argsList->first(); args; args = argsList->next())
{
ds << TQCString(args->id);
@@ -261,7 +261,7 @@ KCmdLineArgs::saveAppArgs( TQDataStream &ds)
}
void
-KCmdLineArgs::loadAppArgs( TQDataStream &ds)
+TDECmdLineArgs::loadAppArgs( TQDataStream &ds)
{
parsed = true; // don't reparse argc/argv!
@@ -269,7 +269,7 @@ KCmdLineArgs::loadAppArgs( TQDataStream &ds)
removeArgs("qt");
removeArgs("tde");
- KCmdLineArgs *args;
+ TDECmdLineArgs *args;
if ( argsList ) {
for(args = argsList->first(); args; args = argsList->next())
{
@@ -307,9 +307,9 @@ KCmdLineArgs::loadAppArgs( TQDataStream &ds)
parsed = true;
}
-KCmdLineArgs *KCmdLineArgs::parsedArgs(const char *id)
+TDECmdLineArgs *TDECmdLineArgs::parsedArgs(const char *id)
{
- KCmdLineArgs *args = argsList ? argsList->first() : 0;
+ TDECmdLineArgs *args = argsList ? argsList->first() : 0;
while(args)
{
if ((id && ::qstrcmp(args->id, id) == 0) || (!id && !args->id))
@@ -324,9 +324,9 @@ KCmdLineArgs *KCmdLineArgs::parsedArgs(const char *id)
return args;
}
-void KCmdLineArgs::removeArgs(const char *id)
+void TDECmdLineArgs::removeArgs(const char *id)
{
- KCmdLineArgs *args = argsList ? argsList->first() : 0;
+ TDECmdLineArgs *args = argsList ? argsList->first() : 0;
while(args)
{
if (args->id && id && ::qstrcmp(args->id, id) == 0)
@@ -426,9 +426,9 @@ findOption(const KCmdLineOptions *options, TQCString &opt,
void
-KCmdLineArgs::findOption(const char *_opt, TQCString opt, int &i, bool _enabled, bool &moreOptions)
+TDECmdLineArgs::findOption(const char *_opt, TQCString opt, int &i, bool _enabled, bool &moreOptions)
{
- KCmdLineArgs *args = argsList->first();
+ TDECmdLineArgs *args = argsList->first();
const char *opt_name;
const char *def;
TQCString argument;
@@ -534,19 +534,19 @@ KCmdLineArgs::findOption(const char *_opt, TQCString opt, int &i, bool _enabled,
}
void
-KCmdLineArgs::printQ(const TQString &msg)
+TDECmdLineArgs::printQ(const TQString &msg)
{
TQCString localMsg = msg.local8Bit();
fprintf(stdout, "%s", localMsg.data());
}
void
-KCmdLineArgs::parseAllArgs()
+TDECmdLineArgs::parseAllArgs()
{
bool allowArgs = false;
bool inOptions = true;
bool everythingAfterArgIsArgs = false;
- KCmdLineArgs *appOptions = argsList->last();
+ TDECmdLineArgs *appOptions = argsList->last();
if (!appOptions->id)
{
const KCmdLineOptions *option = appOptions->options;
@@ -676,7 +676,7 @@ KCmdLineArgs::parseAllArgs()
* Return argc
*/
int *
-KCmdLineArgs::tqt_argc()
+TDECmdLineArgs::tqt_argc()
{
if (!argsList)
KApplication::addCmdLineOptions(); // Lazy bastards!
@@ -685,12 +685,12 @@ KCmdLineArgs::tqt_argc()
if( tqt_argc != -1 )
return &tqt_argc;
- KCmdLineArgs *args = parsedArgs("qt");
+ TDECmdLineArgs *args = parsedArgs("qt");
assert(args); // No qt options have been added!
if (!argv)
{
- fprintf(stderr, "\n\nFAILURE (KCmdLineArgs):\n");
- fprintf(stderr, "Application has not called KCmdLineArgs::init(...).\n\n");
+ fprintf(stderr, "\n\nFAILURE (TDECmdLineArgs):\n");
+ fprintf(stderr, "Application has not called TDECmdLineArgs::init(...).\n\n");
assert( 0 );
exit(255);
@@ -707,7 +707,7 @@ KCmdLineArgs::tqt_argc()
* Return argv
*/
char ***
-KCmdLineArgs::tqt_argv()
+TDECmdLineArgs::tqt_argv()
{
if (!argsList)
KApplication::addCmdLineOptions(); // Lazy bastards!
@@ -716,12 +716,12 @@ KCmdLineArgs::tqt_argv()
if( tqt_argv != NULL )
return &tqt_argv;
- KCmdLineArgs *args = parsedArgs("qt");
+ TDECmdLineArgs *args = parsedArgs("qt");
assert(args); // No qt options have been added!
if (!argv)
{
- fprintf(stderr, "\n\nFAILURE (KCmdLineArgs):\n");
- fprintf(stderr, "Application has not called KCmdLineArgs::init(...).\n\n");
+ fprintf(stderr, "\n\nFAILURE (TDECmdLineArgs):\n");
+ fprintf(stderr, "Application has not called TDECmdLineArgs::init(...).\n\n");
assert( 0 );
exit(255);
@@ -740,7 +740,7 @@ KCmdLineArgs::tqt_argv()
}
void
-KCmdLineArgs::enable_i18n()
+TDECmdLineArgs::enable_i18n()
{
// called twice or too late
if (KGlobal::_locale)
@@ -754,7 +754,7 @@ KCmdLineArgs::enable_i18n()
}
void
-KCmdLineArgs::usage(const TQString &error)
+TDECmdLineArgs::usage(const TQString &error)
{
assert(KGlobal::_locale);
TQCString localError = error.local8Bit();
@@ -769,7 +769,7 @@ KCmdLineArgs::usage(const TQString &error)
}
void
-KCmdLineArgs::usage(const char *id)
+TDECmdLineArgs::usage(const char *id)
{
enable_i18n();
assert(argsList != 0); // It's an error to call usage(...) without
@@ -781,7 +781,7 @@ KCmdLineArgs::usage(const char *id)
TQString tmp;
TQString usage;
- KCmdLineArgs *args = argsList->last();
+ TDECmdLineArgs *args = argsList->last();
if (!(args->id) && (args->options) &&
(args->options->name) && (args->options->name[0] != '+'))
@@ -798,7 +798,7 @@ KCmdLineArgs::usage(const char *id)
args = argsList->prev();
}
- KCmdLineArgs *appOptions = argsList->last();
+ TDECmdLineArgs *appOptions = argsList->last();
if (!appOptions->id)
{
const KCmdLineOptions *option = appOptions->options;
@@ -986,7 +986,7 @@ KCmdLineArgs::usage(const char *id)
*
* The given arguments are assumed to be constants.
*/
-KCmdLineArgs::KCmdLineArgs( const KCmdLineOptions *_options,
+TDECmdLineArgs::TDECmdLineArgs( const KCmdLineOptions *_options,
const char *_name, const char *_id)
: options(_options), name(_name), id(_id)
{
@@ -998,7 +998,7 @@ KCmdLineArgs::KCmdLineArgs( const KCmdLineOptions *_options,
/**
* Destructor.
*/
-KCmdLineArgs::~KCmdLineArgs()
+TDECmdLineArgs::~TDECmdLineArgs()
{
delete parsedOptionList;
delete parsedArgList;
@@ -1007,7 +1007,7 @@ KCmdLineArgs::~KCmdLineArgs()
}
void
-KCmdLineArgs::clear()
+TDECmdLineArgs::clear()
{
delete parsedArgList;
parsedArgList = 0;
@@ -1016,7 +1016,7 @@ KCmdLineArgs::clear()
}
void
-KCmdLineArgs::reset()
+TDECmdLineArgs::reset()
{
if ( argsList ) {
argsList->setAutoDelete( true );
@@ -1028,7 +1028,7 @@ KCmdLineArgs::reset()
}
void
-KCmdLineArgs::save( TQDataStream &ds) const
+TDECmdLineArgs::save( TQDataStream &ds) const
{
uint count = 0;
if (parsedOptionList)
@@ -1043,7 +1043,7 @@ KCmdLineArgs::save( TQDataStream &ds) const
}
void
-KCmdLineArgs::load( TQDataStream &ds)
+TDECmdLineArgs::load( TQDataStream &ds)
{
if (!parsedOptionList) parsedOptionList = new KCmdLineParsedOptions;
if (!parsedArgList) parsedArgList = new KCmdLineParsedArgs;
@@ -1064,7 +1064,7 @@ KCmdLineArgs::load( TQDataStream &ds)
}
void
-KCmdLineArgs::setOption(const TQCString &opt, bool enabled)
+TDECmdLineArgs::setOption(const TQCString &opt, bool enabled)
{
if (isQt)
{
@@ -1087,7 +1087,7 @@ KCmdLineArgs::setOption(const TQCString &opt, bool enabled)
}
void
-KCmdLineArgs::setOption(const TQCString &opt, const char *value)
+TDECmdLineArgs::setOption(const TQCString &opt, const char *value)
{
if (isQt)
{
@@ -1114,7 +1114,7 @@ KCmdLineArgs::setOption(const TQCString &opt, const char *value)
}
TQCString
-KCmdLineArgs::getOption(const char *_opt) const
+TDECmdLineArgs::getOption(const char *_opt) const
{
TQCString *value = 0;
if (parsedOptionList)
@@ -1134,7 +1134,7 @@ KCmdLineArgs::getOption(const char *_opt) const
if (result != 3)
{
- fprintf(stderr, "\n\nFAILURE (KCmdLineArgs):\n");
+ fprintf(stderr, "\n\nFAILURE (TDECmdLineArgs):\n");
fprintf(stderr, "Application requests for getOption(\"%s\") but the \"%s\" option\n",
_opt, _opt);
fprintf(stderr, "has never been specified via addCmdLineOptions( ... )\n\n");
@@ -1146,7 +1146,7 @@ KCmdLineArgs::getOption(const char *_opt) const
}
QCStringList
-KCmdLineArgs::getOptionList(const char *_opt) const
+TDECmdLineArgs::getOptionList(const char *_opt) const
{
QCStringList result;
if (!parsedOptionList)
@@ -1176,7 +1176,7 @@ KCmdLineArgs::getOptionList(const char *_opt) const
}
bool
-KCmdLineArgs::isSet(const char *_opt) const
+TDECmdLineArgs::isSet(const char *_opt) const
{
// Look up the default.
const char *opt_name;
@@ -1187,7 +1187,7 @@ KCmdLineArgs::isSet(const char *_opt) const
if (result == 0)
{
- fprintf(stderr, "\n\nFAILURE (KCmdLineArgs):\n");
+ fprintf(stderr, "\n\nFAILURE (TDECmdLineArgs):\n");
fprintf(stderr, "Application requests for isSet(\"%s\") but the \"%s\" option\n",
_opt, _opt);
fprintf(stderr, "has never been specified via addCmdLineOptions( ... )\n\n");
@@ -1219,7 +1219,7 @@ KCmdLineArgs::isSet(const char *_opt) const
}
int
-KCmdLineArgs::count() const
+TDECmdLineArgs::count() const
{
if (!parsedArgList)
return 0;
@@ -1227,11 +1227,11 @@ KCmdLineArgs::count() const
}
const char *
-KCmdLineArgs::arg(int n) const
+TDECmdLineArgs::arg(int n) const
{
if (!parsedArgList || (n >= (int) parsedArgList->count()))
{
- fprintf(stderr, "\n\nFAILURE (KCmdLineArgs): Argument out of bounds\n");
+ fprintf(stderr, "\n\nFAILURE (TDECmdLineArgs): Argument out of bounds\n");
fprintf(stderr, "Application requests for arg(%d) without checking count() first.\n",
n);
@@ -1243,12 +1243,12 @@ KCmdLineArgs::arg(int n) const
}
KURL
-KCmdLineArgs::url(int n) const
+TDECmdLineArgs::url(int n) const
{
return makeURL( arg(n) );
}
-KURL KCmdLineArgs::makeURL(const char *_urlArg)
+KURL TDECmdLineArgs::makeURL(const char *_urlArg)
{
const TQString urlArg = TQFile::decodeName(_urlArg);
TQFileInfo fileInfo(urlArg);
@@ -1269,7 +1269,7 @@ KURL KCmdLineArgs::makeURL(const char *_urlArg)
}
void
-KCmdLineArgs::addArgument(const char *argument)
+TDECmdLineArgs::addArgument(const char *argument)
{
if (!parsedArgList)
parsedArgList = new KCmdLineParsedArgs;
@@ -1284,14 +1284,14 @@ static const KCmdLineOptions kde_tempfile_option[] =
};
void
-KCmdLineArgs::addTempFileOption()
+TDECmdLineArgs::addTempFileOption()
{
- KCmdLineArgs::addCmdLineOptions( kde_tempfile_option, "TDE-tempfile", "tde-tempfile" );
+ TDECmdLineArgs::addCmdLineOptions( kde_tempfile_option, "TDE-tempfile", "tde-tempfile" );
}
-bool KCmdLineArgs::isTempFileSet()
+bool TDECmdLineArgs::isTempFileSet()
{
- KCmdLineArgs* args = KCmdLineArgs::parsedArgs( "tde-tempfile" );
+ TDECmdLineArgs* args = TDECmdLineArgs::parsedArgs( "tde-tempfile" );
if ( args )
return args->isSet( "tempfile" );
return false;
diff --git a/tdecore/kconfig_compiler/example/autoexample.cpp b/tdecore/kconfig_compiler/example/autoexample.cpp
index 2c4e4d442..494f997f2 100644
--- a/tdecore/kconfig_compiler/example/autoexample.cpp
+++ b/tdecore/kconfig_compiler/example/autoexample.cpp
@@ -41,7 +41,7 @@ int main( int argc, char **argv )
KAboutData aboutData( "example", I18N_NOOP("autoconfig example"), "0.1" );
aboutData.addAuthor( "Cornelius Schumacher", 0, "schumacher@kde.org" );
- KCmdLineArgs::init( argc, argv, &aboutData );
+ TDECmdLineArgs::init( argc, argv, &aboutData );
KApplication app;
diff --git a/tdecore/kconfig_compiler/example/example.cpp b/tdecore/kconfig_compiler/example/example.cpp
index 146d2460f..b1afe7973 100644
--- a/tdecore/kconfig_compiler/example/example.cpp
+++ b/tdecore/kconfig_compiler/example/example.cpp
@@ -35,7 +35,7 @@ int main( int argc, char **argv )
KAboutData aboutData( "example", I18N_NOOP("cfgc example"), "0.1" );
aboutData.addAuthor( "Cornelius Schumacher", 0, "schumacher@kde.org" );
- KCmdLineArgs::init( argc, argv, &aboutData );
+ TDECmdLineArgs::init( argc, argv, &aboutData );
KApplication app;
diff --git a/tdecore/kconfig_compiler/kconfig_compiler.cpp b/tdecore/kconfig_compiler/kconfig_compiler.cpp
index 55a3c7f34..e0b6422a4 100644
--- a/tdecore/kconfig_compiler/kconfig_compiler.cpp
+++ b/tdecore/kconfig_compiler/kconfig_compiler.cpp
@@ -962,12 +962,12 @@ int main( int argc, char **argv )
aboutData.addCredit( "Duncan Mac-Vicar P.", "dpointer support",
"duncan@kde.org", "http://www.mac-vicar.com/~duncan" );
- KCmdLineArgs::init( argc, argv, &aboutData );
- KCmdLineArgs::addCmdLineOptions( options );
+ TDECmdLineArgs::init( argc, argv, &aboutData );
+ TDECmdLineArgs::addCmdLineOptions( options );
KInstance app( &aboutData );
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
if ( args->count() < 2 ) {
kdError() << "Too few arguments." << endl;
diff --git a/tdecore/kdetcompmgr.cpp b/tdecore/kdetcompmgr.cpp
index 8b9b4804e..e7d259628 100644
--- a/tdecore/kdetcompmgr.cpp
+++ b/tdecore/kdetcompmgr.cpp
@@ -46,8 +46,8 @@ int main(int argc, char **argv)
KAboutData about("kdetcompmgr", I18N_NOOP("kdetcompmgr"), version, description,
KAboutData::License_GPL, "(C) 2011 Timothy Pearson", 0, 0, "kb9vqf@pearsoncomputing.net");
about.addAuthor( "Timothy Pearson", 0, "kb9vqf@pearsoncomputing.net" );
- KCmdLineArgs::init(argc, argv, &about);
- KCmdLineArgs::addCmdLineOptions( options );
+ TDECmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::addCmdLineOptions( options );
KApplication app;
diff --git a/tdecore/kinstance.h b/tdecore/kinstance.h
index 5d1dbdce0..56e2e0106 100644
--- a/tdecore/kinstance.h
+++ b/tdecore/kinstance.h
@@ -60,7 +60,7 @@ class TDECORE_EXPORT KInstance
* You have to destroy both, since the instance doesn't own the about data.
* Don't build a KAboutData on the stack in this case !
* Building a KAboutData on the stack is only ok for usage with
- * KCmdLineArgs and KApplication (not destroyed until the app exits).
+ * TDECmdLineArgs and KApplication (not destroyed until the app exits).
* @param aboutData data about this instance (see KAboutData)
*/
KInstance( const KAboutData * aboutData );
diff --git a/tdecore/klockfile.cpp b/tdecore/klockfile.cpp
index bc2175d0d..15f3909b8 100644
--- a/tdecore/klockfile.cpp
+++ b/tdecore/klockfile.cpp
@@ -125,7 +125,7 @@ static KLockFile::LockResult lockFile(const TQString &lockFile, KDE_struct_stat
hostname[0] = 0;
gethostname(hostname, 255);
hostname[255] = 0;
- TQCString instanceName = KCmdLineArgs::appName();
+ TQCString instanceName = TDECmdLineArgs::appName();
(*(uniqueFile.textStream())) << TQString::number(getpid()) << endl
<< instanceName << endl
diff --git a/tdecore/kuniqueapplication.cpp b/tdecore/kuniqueapplication.cpp
index 5f7087313..271264e95 100644
--- a/tdecore/kuniqueapplication.cpp
+++ b/tdecore/kuniqueapplication.cpp
@@ -86,7 +86,7 @@ public:
void
KUniqueApplication::addCmdLineOptions()
{
- KCmdLineArgs::addCmdLineOptions(kunique_options, 0, "kuniqueapp", "tde" );
+ TDECmdLineArgs::addCmdLineOptions(kunique_options, 0, "kuniqueapp", "tde" );
}
bool
@@ -99,12 +99,12 @@ KUniqueApplication::start()
#ifdef Q_WS_WIN
s_nofork = true;
#else
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs("kuniqueapp");
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs("kuniqueapp");
s_nofork = !args->isSet("fork");
delete args;
#endif
- TQCString appName = KCmdLineArgs::about->appName();
+ TQCString appName = TDECmdLineArgs::about->appName();
if (s_nofork)
{
@@ -285,14 +285,14 @@ KUniqueApplication::start()
TQByteArray data, reply;
TQDataStream ds(data, IO_WriteOnly);
- KCmdLineArgs::saveAppArgs(ds);
+ TDECmdLineArgs::saveAppArgs(ds);
ds << new_asn_id;
dc->setPriorityCall(true);
TQCString replyType;
- if (!dc->call(appName, KCmdLineArgs::about->appName(), "newInstance()", data, replyType, reply))
+ if (!dc->call(appName, TDECmdLineArgs::about->appName(), "newInstance()", data, replyType, reply))
{
- kdError() << "Communication problem with " << KCmdLineArgs::about->appName() << ", it probably crashed." << endl;
+ kdError() << "Communication problem with " << TDECmdLineArgs::about->appName() << ", it probably crashed." << endl;
delete dc; // Clean up DCOP commmunication
::exit(255);
}
@@ -316,7 +316,7 @@ KUniqueApplication::start()
KUniqueApplication::KUniqueApplication(bool allowStyles, bool GUIenabled, bool configUnique)
: KApplication( allowStyles, GUIenabled, initHack( configUnique )),
- DCOPObject(KCmdLineArgs::about->appName())
+ DCOPObject(TDECmdLineArgs::about->appName())
{
d = new KUniqueApplicationPrivate;
d->processingRequest = false;
@@ -332,7 +332,7 @@ KUniqueApplication::KUniqueApplication(bool allowStyles, bool GUIenabled, bool c
KUniqueApplication::KUniqueApplication(Display *display, Qt::HANDLE visual,
Qt::HANDLE colormap, bool allowStyles, bool configUnique)
: KApplication( display, visual, colormap, allowStyles, initHack( configUnique )),
- DCOPObject(KCmdLineArgs::about->appName())
+ DCOPObject(TDECmdLineArgs::about->appName())
{
d = new KUniqueApplicationPrivate;
d->processingRequest = false;
@@ -353,7 +353,7 @@ KUniqueApplication::~KUniqueApplication()
// this gets called before even entering TQApplication::TQApplication()
KInstance* KUniqueApplication::initHack( bool configUnique )
{
- KInstance* inst = new KInstance( KCmdLineArgs::about );
+ KInstance* inst = new KInstance( TDECmdLineArgs::about );
if (configUnique)
{
KConfigGroupSaver saver( inst->config(), "KDE" );
@@ -433,7 +433,7 @@ KUniqueApplication::processDelayed()
if (request->fun == "newInstance()") {
dcopClient()->setPriorityCall(false);
TQDataStream ds(request->data, IO_ReadOnly);
- KCmdLineArgs::loadAppArgs(ds);
+ TDECmdLineArgs::loadAppArgs(ds);
if( !ds.atEnd()) // backwards compatibility
{
TQCString asn_id;
diff --git a/tdecore/kuniqueapplication.h b/tdecore/kuniqueapplication.h
index b4ad50129..e9dca8d99 100644
--- a/tdecore/kuniqueapplication.h
+++ b/tdecore/kuniqueapplication.h
@@ -39,7 +39,7 @@ class KUniqueApplicationPrivate;
* see kapplication.h
*
* If your application is used to open files, it should also support the --tempfile
- * option (see KCmdLineArgs::addTempFileOption()), to delete tempfiles after use.
+ * option (see TDECmdLineArgs::addTempFileOption()), to delete tempfiles after use.
* Add X-TDE-HasTempFileOption=true to the .desktop file to indicate this.
*
* @see KApplication DCOPObject
@@ -50,7 +50,7 @@ class TDECORE_EXPORT KUniqueApplication : public KApplication, public DCOPObject
Q_OBJECT
public:
/**
- * Constructor. Takes command line arguments from KCmdLineArgs
+ * Constructor. Takes command line arguments from TDECmdLineArgs
*
* @param allowStyles Set to false to disable the loading on plugin based
* styles. This is only useful to applications that do not display a GUI
@@ -70,7 +70,7 @@ public:
#ifdef Q_WS_X11
/**
- * Constructor. Takes command line arguments from KCmdLineArgs
+ * Constructor. Takes command line arguments from TDECmdLineArgs
*
* @param display Will be passed to Qt as the X display. The display
* must be valid and already opened.
@@ -114,8 +114,8 @@ public:
* \code
* int main(int argc, char **argv) {
* KAboutData about("myappname", "myAppName", .....);
- * KCmdLineArgs::init(argc, argv, &about);
- * KCmdLineArgs::addCmdLineOptions( myCmdOptions );
+ * TDECmdLineArgs::init(argc, argv, &about);
+ * TDECmdLineArgs::addCmdLineOptions( myCmdOptions );
* KUniqueApplication::addCmdLineOptions();
*
* if (!KUniqueApplication::start()) {
@@ -162,7 +162,7 @@ public:
* application asking for a new window to be created, possibly with
* some data already loaded based on the arguments received.
*
- * Command line arguments have been passed to KCmdLineArgs before this
+ * Command line arguments have been passed to TDECmdLineArgs before this
* function is called and can be checked in the usual way.
*
* The default implementation ensures the mainwindow of the already
diff --git a/tdecore/tde-config.cpp.cmake b/tdecore/tde-config.cpp.cmake
index 0afbd9422..58c6407d8 100644
--- a/tdecore/tde-config.cpp.cmake
+++ b/tdecore/tde-config.cpp.cmake
@@ -115,9 +115,9 @@ int main(int argc, char **argv)
{
KLocale::setMainCatalogue("tdelibs");
KAboutData about("tde-config", "tde-config", "1.0", description, KAboutData::License_GPL, "(C) 2000 Stephan Kulow");
- KCmdLineArgs::init( argc, argv, &about);
+ TDECmdLineArgs::init( argc, argv, &about);
- KCmdLineArgs::addCmdLineOptions( options ); // Add my own options.
+ TDECmdLineArgs::addCmdLineOptions( options ); // Add my own options.
KInstance a("tde-config");
a.setConfigReadOnly(TRUE);
@@ -125,7 +125,7 @@ int main(int argc, char **argv)
(void)KGlobal::config();
// Get application specific arguments
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
_expandvars = args->isSet("expandvars");
diff --git a/tdecore/tde-config.cpp.in b/tdecore/tde-config.cpp.in
index c988b000e..10a904e3f 100644
--- a/tdecore/tde-config.cpp.in
+++ b/tdecore/tde-config.cpp.in
@@ -115,9 +115,9 @@ int main(int argc, char **argv)
{
KLocale::setMainCatalogue("tdelibs");
KAboutData about("tde-config", "tde-config", "1.0", description, KAboutData::License_GPL, "(C) 2000 Stephan Kulow");
- KCmdLineArgs::init( argc, argv, &about);
+ TDECmdLineArgs::init( argc, argv, &about);
- KCmdLineArgs::addCmdLineOptions( options ); // Add my own options.
+ TDECmdLineArgs::addCmdLineOptions( options ); // Add my own options.
KInstance a("tde-config");
a.setConfigReadOnly(TRUE);
@@ -125,7 +125,7 @@ int main(int argc, char **argv)
(void)KGlobal::config();
// Get application specific arguments
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
_expandvars = args->isSet("expandvars");
diff --git a/tdecore/tests/kapptest.cpp b/tdecore/tests/kapptest.cpp
index 7e3b47f43..11227517d 100644
--- a/tdecore/tests/kapptest.cpp
+++ b/tdecore/tests/kapptest.cpp
@@ -29,7 +29,7 @@ int
main(int argc, char *argv[])
{
KAboutData about("kapptest", "kapptest", "version");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KApplication a;
diff --git a/tdecore/tests/kcalendartest.cpp b/tdecore/tests/kcalendartest.cpp
index 51a40b892..85f464c9e 100644
--- a/tdecore/tests/kcalendartest.cpp
+++ b/tdecore/tests/kcalendartest.cpp
@@ -39,10 +39,10 @@ int main(int argc, char **argv) {
aboutData.addAuthor("Carlos Moro",0, "cfmoro@correo.uniovi.es");
- KCmdLineArgs::init( argc, argv, &aboutData );
- KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+ TDECmdLineArgs::init( argc, argv, &aboutData );
+ TDECmdLineArgs::addCmdLineOptions( options ); // Add our own options.
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
KApplication app(false, false);
diff --git a/tdecore/tests/kcmdlineargstest.cpp b/tdecore/tests/kcmdlineargstest.cpp
index 299196810..4aa05a48b 100644
--- a/tdecore/tests/kcmdlineargstest.cpp
+++ b/tdecore/tests/kcmdlineargstest.cpp
@@ -25,16 +25,16 @@ int
main(int argc, char *argv[])
{
KLocale::setMainCatalogue("tdelibs");
- KCmdLineArgs::init( argc, argv, "testapp", description, version);
+ TDECmdLineArgs::init( argc, argv, "testapp", description, version);
- KCmdLineArgs::addCmdLineOptions( options ); // Add my own options.
+ TDECmdLineArgs::addCmdLineOptions( options ); // Add my own options.
// MyWidget::addCmdLineOptions();
KApplication k( false, false /*true, true*/ );
// Get application specific arguments
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
// Check if an option is set
if (args->isSet("test"))
{
@@ -79,7 +79,7 @@ main(int argc, char *argv[])
int
main(int argc, char *argv[])
{
- KCmdLineArgs::init( argc, argv, "testapp", description, version);
+ TDECmdLineArgs::init( argc, argv, "testapp", description, version);
KApplication k( true, true );
diff --git a/tdecore/tests/kglobaltest.cpp b/tdecore/tests/kglobaltest.cpp
index d03be209e..8904354c5 100644
--- a/tdecore/tests/kglobaltest.cpp
+++ b/tdecore/tests/kglobaltest.cpp
@@ -54,7 +54,7 @@ void testkasciistricmp()
int main(int argc, char *argv[])
{
KApplication::disableAutoDcopRegistration();
- KCmdLineArgs::init( argc, argv, "kglobaltest", 0, 0, 0, 0 );
+ TDECmdLineArgs::init( argc, argv, "kglobaltest", 0, 0, 0, 0 );
KApplication app( false, false );
testkasciistricmp();
diff --git a/tdecore/tests/kmacroexpandertest.cpp b/tdecore/tests/kmacroexpandertest.cpp
index 0c41a309b..11fb4fd8b 100644
--- a/tdecore/tests/kmacroexpandertest.cpp
+++ b/tdecore/tests/kmacroexpandertest.cpp
@@ -51,7 +51,7 @@ protected:
int main(int argc, char *argv[])
{
- KCmdLineArgs::init(argc, argv, ":", "", "", "");
+ TDECmdLineArgs::init(argc, argv, ":", "", "", "");
KApplication app(false,false);
TQString s, s2;
diff --git a/tdecore/tests/kmdcodectest.cpp b/tdecore/tests/kmdcodectest.cpp
index e74d6f4b4..a6ce6431d 100644
--- a/tdecore/tests/kmdcodectest.cpp
+++ b/tdecore/tests/kmdcodectest.cpp
@@ -334,9 +334,9 @@ int main (int argc, char *argv[])
KCmdLineLastOption
};
- KCmdLineArgs::init( argc, argv, "kmdcodectest", description, version );
- KCmdLineArgs::addCmdLineOptions( options );
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs::init( argc, argv, "kmdcodectest", description, version );
+ TDECmdLineArgs::addCmdLineOptions( options );
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
int count = args->count();
KApplication app;
diff --git a/tdecore/tests/kresolvertest.cpp b/tdecore/tests/kresolvertest.cpp
index 1c2272c11..ca5afe0eb 100644
--- a/tdecore/tests/kresolvertest.cpp
+++ b/tdecore/tests/kresolvertest.cpp
@@ -411,7 +411,7 @@ int TestApp::newInstance(TQValueList<TQCString> /*params*/)
int main(int argc, char **argv)
{
KAboutData about("socktest2", "SockTest", "1.0");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KUniqueApplication::addCmdLineOptions();
/* TestApp a;
diff --git a/tdecore/tests/ksocktest.cpp b/tdecore/tests/ksocktest.cpp
index fe33ec771..62fc74905 100644
--- a/tdecore/tests/ksocktest.cpp
+++ b/tdecore/tests/ksocktest.cpp
@@ -58,7 +58,7 @@ int
main(int argc, char *argv[])
{
KAboutData about("socktest", "SockTest", "version");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KApplication::addCmdLineOptions();
KApplication app;
diff --git a/tdecore/tests/kuniqueapptest.cpp b/tdecore/tests/kuniqueapptest.cpp
index b1d700c8b..f696711a5 100644
--- a/tdecore/tests/kuniqueapptest.cpp
+++ b/tdecore/tests/kuniqueapptest.cpp
@@ -44,7 +44,7 @@ int
main(int argc, char *argv[])
{
KAboutData about("kuniqueapptest", "kuniqueapptest", "version");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KUniqueApplication::addCmdLineOptions();
if (!TestApp::start())
diff --git a/tdecore/tests/kurltest.cpp b/tdecore/tests/kurltest.cpp
index 563eb8937..ddfbc8f7a 100644
--- a/tdecore/tests/kurltest.cpp
+++ b/tdecore/tests/kurltest.cpp
@@ -82,7 +82,7 @@ void testAdjustPath()
int main(int argc, char *argv[])
{
KApplication::disableAutoDcopRegistration();
- KCmdLineArgs::init( argc, argv, "kurltest", 0, 0, 0, 0 );
+ TDECmdLineArgs::init( argc, argv, "kurltest", 0, 0, 0, 0 );
KApplication app( false, false );
KURL::List lst;
diff --git a/tdecore/tests/startserviceby.cpp b/tdecore/tests/startserviceby.cpp
index 93e6716ef..cf9717499 100644
--- a/tdecore/tests/startserviceby.cpp
+++ b/tdecore/tests/startserviceby.cpp
@@ -28,7 +28,7 @@ int
main(int argc, char *argv[])
{
KAboutData about("kapptest", "kapptest", "version");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KApplication a;
diff --git a/tdecore/kapplication.cpp b/tdecore/kapplication.cpp
index 87c5ffb2f..dd804107a 100644
--- a/tdecore/kapplication.cpp
+++ b/tdecore/kapplication.cpp
@@ -640,16 +640,16 @@ KApplication::KApplication( int& argc, char** argv, const TQCString& rAppName,
setName(rAppName);
installSigpipeHandler();
- KCmdLineArgs::initIgnore(argc, argv, rAppName.data());
+ TDECmdLineArgs::initIgnore(argc, argv, rAppName.data());
parseCommandLine( );
init(GUIenabled);
d->m_KAppDCOPInterface = new KAppDCOPInterface(this);
}
KApplication::KApplication( bool allowStyles, bool GUIenabled ) :
-// TQApplication( *KCmdLineArgs::tqt_argc(), *KCmdLineArgs::tqt_argv(), TRUE ), // Qt4 requires that there always be a GUI
- TQApplication( *KCmdLineArgs::tqt_argc(), *KCmdLineArgs::tqt_argv(), GUIenabled ), // We need to be able to run command line apps
- KInstance( KCmdLineArgs::about),
+// TQApplication( *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(), TRUE ), // Qt4 requires that there always be a GUI
+ TQApplication( *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(), GUIenabled ), // We need to be able to run command line apps
+ KInstance( TDECmdLineArgs::about),
#ifdef Q_WS_X11
display(0L),
argb_visual(false),
@@ -672,9 +672,9 @@ KApplication::KApplication( bool allowStyles, bool GUIenabled ) :
#ifdef Q_WS_X11
KApplication::KApplication( Display *dpy, bool allowStyles ) :
- TQApplication( dpy, *KCmdLineArgs::tqt_argc(), *KCmdLineArgs::tqt_argv(),
+ TQApplication( dpy, *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(),
getX11RGBAVisual(dpy), getX11RGBAColormap(dpy) ),
- KInstance( KCmdLineArgs::about), display(0L), d (new KApplicationPrivate)
+ KInstance( TDECmdLineArgs::about), display(0L), d (new KApplicationPrivate)
{
aIconPixmap.pm.icon = 0L;
aIconPixmap.pm.miniIcon = 0L;
@@ -688,9 +688,9 @@ KApplication::KApplication( Display *dpy, bool allowStyles ) :
}
KApplication::KApplication( Display *dpy, bool disable_argb, Qt::HANDLE visual, Qt::HANDLE colormap, bool allowStyles ) :
- TQApplication( dpy, *KCmdLineArgs::tqt_argc(), *KCmdLineArgs::tqt_argv(),
+ TQApplication( dpy, *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(),
disable_argb?visual:getX11RGBAVisual(dpy), disable_argb?colormap:getX11RGBAColormap(dpy) ),
- KInstance( KCmdLineArgs::about), display(0L), d (new KApplicationPrivate)
+ KInstance( TDECmdLineArgs::about), display(0L), d (new KApplicationPrivate)
{
aIconPixmap.pm.icon = 0L;
aIconPixmap.pm.miniIcon = 0L;
@@ -706,9 +706,9 @@ KApplication::KApplication( Display *dpy, bool disable_argb, Qt::HANDLE visual,
KApplication::KApplication( Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap,
bool allowStyles ) :
- TQApplication( dpy, *KCmdLineArgs::tqt_argc(), *KCmdLineArgs::tqt_argv(),
+ TQApplication( dpy, *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(),
visual?visual:getX11RGBAVisual(dpy), colormap?colormap:getX11RGBAColormap(dpy) ),
- KInstance( KCmdLineArgs::about), display(0L), d (new KApplicationPrivate)
+ KInstance( TDECmdLineArgs::about), display(0L), d (new KApplicationPrivate)
{
if ((visual) && (colormap))
getX11RGBAInformation(dpy);
@@ -725,7 +725,7 @@ KApplication::KApplication( Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap
KApplication::KApplication( Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap,
bool allowStyles, KInstance * _instance ) :
- TQApplication( dpy, *KCmdLineArgs::tqt_argc(), *KCmdLineArgs::tqt_argv(),
+ TQApplication( dpy, *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(),
visual?visual:getX11RGBAVisual(dpy), colormap?colormap:getX11RGBAColormap(dpy) ),
KInstance( _instance ), display(0L), d (new KApplicationPrivate)
{
@@ -744,7 +744,7 @@ KApplication::KApplication( Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap
#endif
KApplication::KApplication( bool allowStyles, bool GUIenabled, KInstance* _instance ) :
- TQApplication( *KCmdLineArgs::tqt_argc(), *KCmdLineArgs::tqt_argv(),
+ TQApplication( *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(),
GUIenabled ),
KInstance( _instance ),
#ifdef Q_WS_X11
@@ -786,7 +786,7 @@ KApplication::KApplication(Display *display, int& argc, char** argv, const TQCSt
setName(rAppName);
installSigpipeHandler();
- KCmdLineArgs::initIgnore(argc, argv, rAppName.data());
+ TDECmdLineArgs::initIgnore(argc, argv, rAppName.data());
parseCommandLine( );
init(GUIenabled);
d->m_KAppDCOPInterface = new KAppDCOPInterface(this);
@@ -977,7 +977,7 @@ void KApplication::init(bool GUIenabled)
#ifdef Q_WS_MACX
if (GUIenabled) {
- TQPixmap pixmap = KGlobal::iconLoader()->loadIcon( KCmdLineArgs::appName(),
+ TQPixmap pixmap = KGlobal::iconLoader()->loadIcon( TDECmdLineArgs::appName(),
KIcon::NoGroup, KIcon::SizeLarge, KIcon::DefaultState, 0L, false );
if (!pixmap.isNull()) {
TQImage i = pixmap.convertToImage().convertDepth(32).smoothScale(40, 40);
@@ -1063,7 +1063,7 @@ DCOPClient *KApplication::dcopClient()
return s_DCOPClient;
s_DCOPClient = new DCOPClient();
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs("tde");
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs("tde");
if (args && args->isSet("dcopserver"))
{
s_DCOPClient->setServerAddress( args->getOption("dcopserver"));
@@ -1562,13 +1562,13 @@ static const KCmdLineOptions kde_options[] =
void
KApplication::addCmdLineOptions()
{
- KCmdLineArgs::addCmdLineOptions(qt_options, "Qt", "qt");
- KCmdLineArgs::addCmdLineOptions(kde_options, "TDE", "tde");
+ TDECmdLineArgs::addCmdLineOptions(qt_options, "Qt", "qt");
+ TDECmdLineArgs::addCmdLineOptions(kde_options, "TDE", "tde");
}
void KApplication::parseCommandLine( )
{
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs("tde");
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs("tde");
if ( !args ) return;
@@ -1823,7 +1823,7 @@ bool KApplication::detectCompositionManagerAvailable(bool force_available, bool
}
else {
// See if compositing has been enabled
- KCmdLineArgs *qtargs = KCmdLineArgs::parsedArgs("qt");
+ TDECmdLineArgs *qtargs = TDECmdLineArgs::parsedArgs("qt");
char *displayname = 0;
if ( qtargs->isSet("display"))
displayname = qtargs->getOption( "display" ).data();
@@ -1896,7 +1896,7 @@ bool KApplication::detectCompositionManagerAvailable(bool force_available, bool
}
Display* KApplication::openX11RGBADisplay() {
- KCmdLineArgs *qtargs = KCmdLineArgs::parsedArgs("qt");
+ TDECmdLineArgs *qtargs = TDECmdLineArgs::parsedArgs("qt");
char *display = 0;
if ( qtargs->isSet("display"))
display = qtargs->getOption( "display" ).data();
diff --git a/tdecore/kcmdlineargs.h b/tdecore/kcmdlineargs.h
index 7b6a33e2e..0b89fd3bb 100644
--- a/tdecore/kcmdlineargs.h
+++ b/tdecore/kcmdlineargs.h
@@ -31,11 +31,11 @@ typedef TQValueList<TQCString> QCStringList;
/**
* @short Structure that holds command line options.
*
* This class is intended to be used with the KCmdLineArgs class, which
* provides convenient and powerful command line argument parsing and
* handling functionality.
*
* @see KCmdLineArgs for additional usage information
*/
struct TDECORE_EXPORT KCmdLineOptions
{
@@ -49,7 +49,7 @@ struct TDECORE_EXPORT KCmdLineOptions
* <i>myapp --nofoo</i> is called:
*
* \code
- * KCmdLineArgs::parsedArgs()->isSet("foo"); // false
+ * TDECmdLineArgs::parsedArgs()->isSet("foo"); // false
* \endcode
*/
const char *name;
@@ -67,34 +67,34 @@ struct TDECORE_EXPORT KCmdLineOptions
#define KCmdLineLastOption { 0, 0, 0 }
-class KCmdLineArgsList;
+class TDECmdLineArgsList;
class KApplication;
class KUniqueApplication;
class KCmdLineParsedOptions;
class KCmdLineParsedArgs;
class KAboutData;
-class KCmdLineArgsPrivate;
+class TDECmdLineArgsPrivate;
/**
* @short A class for command-line argument handling.
*
* KCmdLineArgs provides simple access to the command-line arguments
* for an application. It takes into account Qt-specific options,
* KDE-specific options and application specific options.
*
* This class is used in %main() via the static method
* init().
*
* A typical %KDE application using %KCmdLineArgs should look like this:
*
* \code
* int main(int argc, char *argv[])
* {
* // Initialize command line args
- * KCmdLineArgs::init(argc, argv, appName, programName, description, version);
+ * TDECmdLineArgs::init(argc, argv, appName, programName, description, version);
*
* // Tell which options are supported
- * KCmdLineArgs::addCmdLineOptions( options );
+ * TDECmdLineArgs::addCmdLineOptions( options );
*
* // Add options from other components
* KUniqueApplication::addCmdLineOptions();
@@ -111,7 +111,7 @@ class KCmdLineArgsPrivate;
* // necessary.
* // A KUniqueApplication might want to handle it in newInstance().
*
- * KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ * TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
*
* // A binary option (on / off)
* if (args->isSet("some-option"))
@@ -165,7 +165,7 @@ class KCmdLineArgsPrivate;
* \endcode
*
* The I18N_NOOP macro is used to indicate that these strings should be
* marked for translation. The actual translation is done by KCmdLineArgs.
* You can't use i18n() here because we are setting up a static data
* structure and can't do translations at compile time.
*
@@ -219,11 +219,11 @@ class KCmdLineArgsPrivate;
* @author Waldo Bastian
* @version 0.0.4
*/
-class TDECORE_EXPORT KCmdLineArgs
+class TDECORE_EXPORT TDECmdLineArgs
{
friend class KApplication;
friend class KUniqueApplication;
- friend class TQPtrList<KCmdLineArgs>;
+ friend class TQPtrList<TDECmdLineArgs>;
public:
// Static functions:
@@ -321,8 +321,8 @@ public:
* true. If required, you must check yourself the number of arguments
* specified by the user:
* \code
- * KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
- * if (args->count() == 0) KCmdLineArgs::usage(i18n("No file specified!"));
+ * TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
+ * if (args->count() == 0) TDECmdLineArgs::usage(i18n("No file specified!"));
* \endcode
*
* In BNF:
@@ -367,7 +367,7 @@ public:
*
* @param id The name of the options you are interested in, can be 0.
*/
- static KCmdLineArgs *parsedArgs(const char *id=0);
+ static TDECmdLineArgs *parsedArgs(const char *id=0);
/**
* Get the CWD (Current Working Directory) associated with the
@@ -501,14 +501,14 @@ public:
/**
* Used by url().
* Made public for apps that don't use KCmdLineArgs
* @param urlArg the argument
* @return the url.
*/
static KURL makeURL( const char * urlArg );
/**
* Made public for apps that don't use KCmdLineArgs
* To be done before makeURL, to set the current working
* directory in case makeURL needs it.
* @param cwd the new working directory
@@ -553,7 +553,7 @@ protected:
* @internal
* Constructor.
*/
- KCmdLineArgs( const KCmdLineOptions *_options, const char *_name,
+ TDECmdLineArgs( const KCmdLineOptions *_options, const char *_name,
const char *_id);
/**
@@ -563,7 +563,7 @@ protected:
*
* Destructor.
*/
- ~KCmdLineArgs();
+ ~TDECmdLineArgs();
private:
/**
@@ -659,7 +659,7 @@ private:
* @param appname The untranslated name of your application. This should
* match with @p argv[0].
*
* This function makes KCmdLineArgs ignore all unknown options as well as
* all arguments.
*/
static void initIgnore(int _argc, char **_argv, const char *_appname);
@@ -673,7 +673,7 @@ private:
KCmdLineParsedArgs *parsedArgList;
bool isQt;
- static KCmdLineArgsList *argsList; // All options.
+ static TDECmdLineArgsList *argsList; // All options.
static const KAboutData *about;
static int argc; // The original argc
@@ -683,7 +683,7 @@ private:
static char *mCwd; // Current working directory. Important for KUnqiueApp!
static bool parseArgs;
- KCmdLineArgsPrivate *d;
+ TDECmdLineArgsPrivate *d;
};
#endif
@@ -31,11 +31,11 @@ typedef TQValueList<TQCString> QCStringList;
* @short Structure that holds command line options.
*
- * This class is intended to be used with the KCmdLineArgs class, which
+ * This class is intended to be used with the TDECmdLineArgs class, which
* provides convenient and powerful command line argument parsing and
* handling functionality.
@@ -31,11 +31,11 @@ typedef TQValueList<TQCString> QCStringList;
* handling functionality.
*
- * @see KCmdLineArgs for additional usage information
+ * @see TDECmdLineArgs for additional usage information
*/
struct TDECORE_EXPORT KCmdLineOptions
@@ -67,34 +67,34 @@ struct TDECORE_EXPORT KCmdLineOptions
* @short A class for command-line argument handling.
*
- * KCmdLineArgs provides simple access to the command-line arguments
+ * TDECmdLineArgs provides simple access to the command-line arguments
* for an application. It takes into account Qt-specific options,
* KDE-specific options and application specific options.
@@ -67,34 +67,34 @@ struct TDECORE_EXPORT KCmdLineOptions
* init().
*
- * A typical %KDE application using %KCmdLineArgs should look like this:
+ * A typical %KDE application using %TDECmdLineArgs should look like this:
*
* \code
@@ -165,7 +165,7 @@ class KCmdLineArgsPrivate;
*
* The I18N_NOOP macro is used to indicate that these strings should be
- * marked for translation. The actual translation is done by KCmdLineArgs.
+ * marked for translation. The actual translation is done by TDECmdLineArgs.
* You can't use i18n() here because we are setting up a static data
* structure and can't do translations at compile time.
@@ -501,14 +501,14 @@ public:
/**
* Used by url().
- * Made public for apps that don't use KCmdLineArgs
+ * Made public for apps that don't use TDECmdLineArgs
* @param urlArg the argument
* @return the url.
@@ -501,14 +501,14 @@ public:
static KURL makeURL( const char * urlArg );
/**
- * Made public for apps that don't use KCmdLineArgs
+ * Made public for apps that don't use TDECmdLineArgs
* To be done before makeURL, to set the current working
* directory in case makeURL needs it.
@@ -659,7 +659,7 @@ private:
* match with @p argv[0].
*
- * This function makes KCmdLineArgs ignore all unknown options as well as
+ * This function makes TDECmdLineArgs ignore all unknown options as well as
* all arguments.
*/
diff --git a/tdecore/tests/testqtargs.cpp b/tdecore/tests/testqtargs.cpp
index c9e933c51..97c545e1e 100644
--- a/tdecore/tests/testqtargs.cpp
+++ b/tdecore/tests/testqtargs.cpp
@@ -1,5 +1,5 @@
/*
- testqtargs -- is there really a bug in KCmdLineArgs or am I on crack?
+ testqtargs -- is there really a bug in TDECmdLineArgs or am I on crack?
I used the following compile options:
@@ -64,10 +64,10 @@ int main(int argc, char *argv[])
"1.0", I18N_NOOP("testqtargs"), KAboutData::License_GPL,
"", "", "", "");
- KCmdLineArgs::init(argc, argv, &aboutData);
- KCmdLineArgs::addCmdLineOptions(options);
+ TDECmdLineArgs::init(argc, argv, &aboutData);
+ TDECmdLineArgs::addCmdLineOptions(options);
- KCmdLineArgs *qtargs = KCmdLineArgs::parsedArgs("qt");
+ TDECmdLineArgs *qtargs = TDECmdLineArgs::parsedArgs("qt");
for (int i = 0; i < qtargs->count(); i++)
{
tqDebug("qt arg[%d] = %s", i, qtargs->arg(i));
@@ -75,8 +75,8 @@ int main(int argc, char *argv[])
KApplication app;
- KCmdLineArgs *kdeargs = KCmdLineArgs::parsedArgs("tde");
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *kdeargs = TDECmdLineArgs::parsedArgs("tde");
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
// An arg set by Qt
if(qtargs->isSet("background"))